# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/geography/geography.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.geography import country_pb2 as eolymp_dot_geography_dot_country__pb2
from eolymp.geography import region_pb2 as eolymp_dot_geography_dot_region__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/geography/geography.proto\x12\x10\x65olymp.geography\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/geography/country.proto\x1a\x1d\x65olymp/geography/region.proto\"*\n\x14\x44\x65scribeCountryInput\x12\x12\n\ncountry_id\x18\x01 \x01(\t\"C\n\x15\x44\x65scribeCountryOutput\x12*\n\x07\x63ountry\x18\x01 \x01(\x0b\x32\x19.eolymp.geography.Country\"\x14\n\x12ListCountriesInput\"N\n\x13ListCountriesOutput\x12(\n\x05items\x18\x01 \x03(\x0b\x32\x19.eolymp.geography.Country\x12\r\n\x05total\x18\x02 \x01(\x05\"(\n\x13\x44\x65scribeRegionInput\x12\x11\n\tregion_id\x18\x01 \x01(\t\"@\n\x14\x44\x65scribeRegionOutput\x12(\n\x06region\x18\x01 \x01(\x0b\x32\x18.eolymp.geography.Region\"&\n\x10ListRegionsInput\x12\x12\n\ncountry_id\x18\x01 \x01(\t\"K\n\x11ListRegionsOutput\x12\'\n\x05items\x18\x01 \x03(\x0b\x32\x18.eolymp.geography.Region\x12\r\n\x05total\x18\x02 \x01(\x05\x32\xee\x04\n\tGeography\x12\x9d\x01\n\x0f\x44\x65scribeCountry\x12&.eolymp.geography.DescribeCountryInput\x1a\'.eolymp.geography.DescribeCountryOutput\"9\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02#\x12!/geography/countries/{country_id}\x12\x8a\x01\n\rListCountries\x12$.eolymp.geography.ListCountriesInput\x1a%.eolymp.geography.ListCountriesOutput\",\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x16\x12\x14/geography/countries\x12\x97\x01\n\x0e\x44\x65scribeRegion\x12%.eolymp.geography.DescribeRegionInput\x1a&.eolymp.geography.DescribeRegionOutput\"6\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02 \x12\x1e/geography/regions/{region_id}\x12\x99\x01\n\x0bListRegions\x12\".eolymp.geography.ListRegionsInput\x1a#.eolymp.geography.ListRegionsOutput\"A\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02+\x12)/geography/countries/{country_id}/regionsB5Z3github.com/eolymp/go-sdk/eolymp/geography;geographyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.geography.geography_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/geography;geography'
  _GEOGRAPHY.methods_by_name['DescribeCountry']._options = None
  _GEOGRAPHY.methods_by_name['DescribeCountry']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002#\022!/geography/countries/{country_id}'
  _GEOGRAPHY.methods_by_name['ListCountries']._options = None
  _GEOGRAPHY.methods_by_name['ListCountries']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\026\022\024/geography/countries'
  _GEOGRAPHY.methods_by_name['DescribeRegion']._options = None
  _GEOGRAPHY.methods_by_name['DescribeRegion']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002 \022\036/geography/regions/{region_id}'
  _GEOGRAPHY.methods_by_name['ListRegions']._options = None
  _GEOGRAPHY.methods_by_name['ListRegions']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002+\022)/geography/countries/{country_id}/regions'
  _DESCRIBECOUNTRYINPUT._serialized_start=184
  _DESCRIBECOUNTRYINPUT._serialized_end=226
  _DESCRIBECOUNTRYOUTPUT._serialized_start=228
  _DESCRIBECOUNTRYOUTPUT._serialized_end=295
  _LISTCOUNTRIESINPUT._serialized_start=297
  _LISTCOUNTRIESINPUT._serialized_end=317
  _LISTCOUNTRIESOUTPUT._serialized_start=319
  _LISTCOUNTRIESOUTPUT._serialized_end=397
  _DESCRIBEREGIONINPUT._serialized_start=399
  _DESCRIBEREGIONINPUT._serialized_end=439
  _DESCRIBEREGIONOUTPUT._serialized_start=441
  _DESCRIBEREGIONOUTPUT._serialized_end=505
  _LISTREGIONSINPUT._serialized_start=507
  _LISTREGIONSINPUT._serialized_end=545
  _LISTREGIONSOUTPUT._serialized_start=547
  _LISTREGIONSOUTPUT._serialized_end=622
  _GEOGRAPHY._serialized_start=625
  _GEOGRAPHY._serialized_end=1247
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.course import course_pb2 as _course_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateCourseInput(_message.Message):
    __slots__ = ["course"]
    COURSE_FIELD_NUMBER: _ClassVar[int]
    course: _course_pb2.Course
    def __init__(self, course: _Optional[_Union[_course_pb2.Course, _Mapping]] = ...) -> None: ...

class CreateCourseOutput(_message.Message):
    __slots__ = ["course_id"]
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    course_id: str
    def __init__(self, course_id: _Optional[str] = ...) -> None: ...

class DeleteCourseInput(_message.Message):
    __slots__ = ["course_id"]
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    course_id: str
    def __init__(self, course_id: _Optional[str] = ...) -> None: ...

class DeleteCourseOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeCourseInput(_message.Message):
    __slots__ = ["course_id", "render"]
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    course_id: str
    render: bool
    def __init__(self, course_id: _Optional[str] = ..., render: bool = ...) -> None: ...

class DescribeCourseOutput(_message.Message):
    __slots__ = ["course"]
    COURSE_FIELD_NUMBER: _ClassVar[int]
    course: _course_pb2.Course
    def __init__(self, course: _Optional[_Union[_course_pb2.Course, _Mapping]] = ...) -> None: ...

class ListCoursesInput(_message.Message):
    __slots__ = ["filters", "offset", "order", "render", "size", "sort"]
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Filter(_message.Message):
        __slots__ = ["id", "locale", "query", "topic_id"]
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        query: str
        topic_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., topic_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    DEFAULT: ListCoursesInput.Sortable
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    filters: ListCoursesInput.Filter
    offset: int
    order: _direction_pb2.Direction
    render: bool
    size: int
    sort: ListCoursesInput.Sortable
    def __init__(self, render: bool = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListCoursesInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListCoursesInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ...) -> None: ...

class ListCoursesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_course_pb2.Course]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_course_pb2.Course, _Mapping]]] = ...) -> None: ...

class UpdateCourseInput(_message.Message):
    __slots__ = ["course", "course_id", "patch"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateCourseInput.Patch
    COURSE_FIELD_NUMBER: _ClassVar[int]
    COURSE_ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION: UpdateCourseInput.Patch
    DURATION: UpdateCourseInput.Patch
    IMAGE: UpdateCourseInput.Patch
    LOCALE: UpdateCourseInput.Patch
    NAME: UpdateCourseInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    TOPICS: UpdateCourseInput.Patch
    VISIBILITY: UpdateCourseInput.Patch
    course: _course_pb2.Course
    course_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateCourseInput.Patch]
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateCourseInput.Patch, str]]] = ..., course_id: _Optional[str] = ..., course: _Optional[_Union[_course_pb2.Course, _Mapping]] = ...) -> None: ...

class UpdateCourseOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/problem_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import library_service_pb2 as eolymp_dot_atlas_dot_library__service__pb2
from eolymp.atlas import version_pb2 as eolymp_dot_atlas_dot_version__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/problem_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/atlas/library_service.proto\x1a\x1a\x65olymp/atlas/version.proto\x1a!eolymp/wellknown/expression.proto\"\x97\x03\n\x11ListVersionsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.atlas.ListVersionsInput.Filter\x1a\x96\x02\n\x06\x46ilter\x12/\n\x06number\x18\x01 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x32\n\ncreated_by\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x39\n\ncreated_at\x18\x03 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x33\n\tchange_op\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x37\n\x0b\x63hange_path\x18\x05 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"I\n\x12ListVersionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.atlas.Version2\xf3\x07\n\x0eProblemService\x12\x88\x01\n\rDeleteProblem\x12 .eolymp.atlas.DeleteProblemInput\x1a!.eolymp.atlas.DeleteProblemOutput\"2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x02*\x00\x12\x88\x01\n\rUpdateProblem\x12 .eolymp.atlas.UpdateProblemInput\x1a!.eolymp.atlas.UpdateProblemOutput\"2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x02\x1a\x00\x12\x87\x01\n\x0bSyncProblem\x12\x1e.eolymp.atlas.SyncProblemInput\x1a\x1f.eolymp.atlas.SyncProblemOutput\"7\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x07\"\x05/sync\x12\x8d\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.atlas.DescribeProblemInput\x1a#.eolymp.atlas.DescribeProblemOutput\"1\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x02\x12\x00\x12\x9c\x01\n\x10UpdateVisibility\x12#.eolymp.atlas.UpdateVisibilityInput\x1a$.eolymp.atlas.UpdateVisibilityOutput\"=\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\r\"\x0b/visibility\x12\x90\x01\n\rUpdatePrivacy\x12 .eolymp.atlas.UpdatePrivacyInput\x1a!.eolymp.atlas.UpdatePrivacyOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\n\"\x08/privacy\x12\x7f\n\x0cListVersions\x12\x1f.eolymp.atlas.ListVersionsInput\x1a .eolymp.atlas.ListVersionsOutput\",\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0b\x12\t/versionsB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.problem_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _PROBLEMSERVICE.methods_by_name['DeleteProblem']._options = None
  _PROBLEMSERVICE.methods_by_name['DeleteProblem']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\002*\000'
  _PROBLEMSERVICE.methods_by_name['UpdateProblem']._options = None
  _PROBLEMSERVICE.methods_by_name['UpdateProblem']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\002\032\000'
  _PROBLEMSERVICE.methods_by_name['SyncProblem']._options = None
  _PROBLEMSERVICE.methods_by_name['SyncProblem']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\007\"\005/sync'
  _PROBLEMSERVICE.methods_by_name['DescribeProblem']._options = None
  _PROBLEMSERVICE.methods_by_name['DescribeProblem']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\002\022\000'
  _PROBLEMSERVICE.methods_by_name['UpdateVisibility']._options = None
  _PROBLEMSERVICE.methods_by_name['UpdateVisibility']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\r\"\013/visibility'
  _PROBLEMSERVICE.methods_by_name['UpdatePrivacy']._options = None
  _PROBLEMSERVICE.methods_by_name['UpdatePrivacy']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\n\"\010/privacy'
  _PROBLEMSERVICE.methods_by_name['ListVersions']._options = None
  _PROBLEMSERVICE.methods_by_name['ListVersions']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\013\022\t/versions'
  _LISTVERSIONSINPUT._serialized_start=251
  _LISTVERSIONSINPUT._serialized_end=658
  _LISTVERSIONSINPUT_FILTER._serialized_start=380
  _LISTVERSIONSINPUT_FILTER._serialized_end=658
  _LISTVERSIONSOUTPUT._serialized_start=660
  _LISTVERSIONSOUTPUT._serialized_end=733
  _PROBLEMSERVICE._serialized_start=736
  _PROBLEMSERVICE._serialized_end=1747
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.discussion import discussion_pb2 as _discussion_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateDiscussionInput(_message.Message):
    __slots__ = ["discussion"]
    DISCUSSION_FIELD_NUMBER: _ClassVar[int]
    discussion: _discussion_pb2.Discussion
    def __init__(self, discussion: _Optional[_Union[_discussion_pb2.Discussion, _Mapping]] = ...) -> None: ...

class CreateDiscussionOutput(_message.Message):
    __slots__ = ["discussion_id"]
    DISCUSSION_ID_FIELD_NUMBER: _ClassVar[int]
    discussion_id: str
    def __init__(self, discussion_id: _Optional[str] = ...) -> None: ...

class DeleteDiscussionInput(_message.Message):
    __slots__ = ["discussion_id"]
    DISCUSSION_ID_FIELD_NUMBER: _ClassVar[int]
    discussion_id: str
    def __init__(self, discussion_id: _Optional[str] = ...) -> None: ...

class DeleteDiscussionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeDiscussionInput(_message.Message):
    __slots__ = ["discussion_id", "render"]
    DISCUSSION_ID_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    discussion_id: str
    render: bool
    def __init__(self, discussion_id: _Optional[str] = ..., render: bool = ...) -> None: ...

class DescribeDiscussionOutput(_message.Message):
    __slots__ = ["discussion"]
    DISCUSSION_FIELD_NUMBER: _ClassVar[int]
    discussion: _discussion_pb2.Discussion
    def __init__(self, discussion: _Optional[_Union[_discussion_pb2.Discussion, _Mapping]] = ...) -> None: ...

class ListDiscussionsInput(_message.Message):
    __slots__ = ["filters", "offset", "render", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    RENDER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListDiscussionsInput.Filter
    offset: int
    render: bool
    size: int
    def __init__(self, render: bool = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListDiscussionsInput.Filter, _Mapping]] = ...) -> None: ...

class ListDiscussionsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_discussion_pb2.Discussion]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_discussion_pb2.Discussion, _Mapping]]] = ...) -> None: ...

class UpdateDiscussionInput(_message.Message):
    __slots__ = ["discussion", "discussion_id"]
    DISCUSSION_FIELD_NUMBER: _ClassVar[int]
    DISCUSSION_ID_FIELD_NUMBER: _ClassVar[int]
    discussion: _discussion_pb2.Discussion
    discussion_id: str
    def __init__(self, discussion_id: _Optional[str] = ..., discussion: _Optional[_Union[_discussion_pb2.Discussion, _Mapping]] = ...) -> None: ...

class UpdateDiscussionOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class VoteDiscussionInput(_message.Message):
    __slots__ = ["discussion_id", "vote"]
    DISCUSSION_ID_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    discussion_id: str
    vote: int
    def __init__(self, discussion_id: _Optional[str] = ..., vote: _Optional[int] = ...) -> None: ...

class VoteDiscussionOutput(_message.Message):
    __slots__ = ["vote_count"]
    VOTE_COUNT_FIELD_NUMBER: _ClassVar[int]
    vote_count: int
    def __init__(self, vote_count: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Subscription(_message.Message):
    __slots__ = ["type"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    MUTED: Subscription.Type
    NONE: Subscription.Type
    SUBSCRIBED: Subscription.Type
    TYPE_FIELD_NUMBER: _ClassVar[int]
    WATCHING: Subscription.Type
    type: Subscription.Type
    def __init__(self, type: _Optional[_Union[Subscription.Type, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class CognitoClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def Signout(self, request, **kwargs):
        path = "/self/signout"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.SignoutOutput"),
            **kwargs,
        )

    def CreateAccessKey(self, request, **kwargs):
        path = "/access-keys"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.CreateAccessKeyOutput"),
            **kwargs,
        )

    def DeleteAccessKey(self, request, **kwargs):
        path = "/access-keys/"+urllib.parse.quote(request.key_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.key_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.DeleteAccessKeyOutput"),
            **kwargs,
        )

    def ListAccessKeys(self, request, **kwargs):
        path = "/access-keys"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.ListAccessKeysOutput"),
            **kwargs,
        )

    def CreateUser(self, request, **kwargs):
        path = "/users"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.CreateUserOutput"),
            **kwargs,
        )

    def VerifyEmail(self, request, **kwargs):
        path = "/users/"+urllib.parse.quote(request.user_id)+"/verify"

        # Cleanup URL parameters to avoid any ambiguity
        request.user_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.VerifyEmailOutput"),
            **kwargs,
        )

    def ResendEmailVerification(self, request, **kwargs):
        path = "/self/email/resend-verification"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.ResendEmailVerificationOutput"),
            **kwargs,
        )

    def UpdateEmail(self, request, **kwargs):
        path = "/self/email"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.UpdateEmailOutput"),
            **kwargs,
        )

    def UpdateProfile(self, request, **kwargs):
        path = "/self"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.UpdateProfileOutput"),
            **kwargs,
        )

    def UpdatePicture(self, request, **kwargs):
        path = "/self/picture"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.UpdatePictureOutput"),
            **kwargs,
        )

    def UpdatePassword(self, request, **kwargs):
        path = "/self/password"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.UpdatePasswordOutput"),
            **kwargs,
        )

    def IntrospectUser(self, request, **kwargs):
        path = "/self"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.IntrospectUserOutput"),
            **kwargs,
        )

    def DescribeUser(self, request, **kwargs):
        path = "/users/"+urllib.parse.quote(request.user_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.user_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.DescribeUserOutput"),
            **kwargs,
        )

    def ListUsers(self, request, **kwargs):
        path = "/users"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.ListUsersOutput"),
            **kwargs,
        )

    def IntrospectQuota(self, request, **kwargs):
        path = "/self/quota"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.IntrospectQuotaOutput"),
            **kwargs,
        )

    def IntrospectRoles(self, request, **kwargs):
        path = "/self/roles"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.IntrospectRolesOutput"),
            **kwargs,
        )

    def ListRoles(self, request, **kwargs):
        path = "/users/"+urllib.parse.quote(request.user_id)+"/roles"

        # Cleanup URL parameters to avoid any ambiguity
        request.user_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.ListRolesOutput"),
            **kwargs,
        )

    def UpdateRoles(self, request, **kwargs):
        path = "/users/"+urllib.parse.quote(request.user_id)+"/roles"

        # Cleanup URL parameters to avoid any ambiguity
        request.user_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.UpdateRolesOutput"),
            **kwargs,
        )

    def StartRecovery(self, request, **kwargs):
        path = "/self/recovery"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.StartRecoveryOutput"),
            **kwargs,
        )

    def CompleteRecovery(self, request, **kwargs):
        path = "/users/"+urllib.parse.quote(request.user_id)+"/recover"

        # Cleanup URL parameters to avoid any ambiguity
        request.user_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.CompleteRecoverOutput"),
            **kwargs,
        )

    def SelfDestruct(self, request, **kwargs):
        path = "/self"

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.cognito.SelfDestructOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/report.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import usage_pb2 as eolymp_dot_executor_dot_usage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/executor/report.proto\x12\x0f\x65olymp.executor\x1a\x1b\x65olymp/executor/usage.proto\"\xf6\x0c\n\x06Report\x12\x11\n\treference\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x12\n\nagent_name\x18n \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\x12,\n\x05state\x18\n \x01(\x0e\x32\x1d.eolymp.executor.Report.State\x12-\n\x06\x61\x63tors\x18\x32 \x03(\x0b\x32\x1d.eolymp.executor.Report.Actor\x12)\n\x04runs\x18( \x03(\x0b\x32\x1b.eolymp.executor.Report.Run\x12\r\n\x05\x65rror\x18\x14 \x01(\t\x1a\xa9\x01\n\x05\x41\x63tor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\t\x12\x37\n\nerror_code\x18\n \x01(\x0e\x32#.eolymp.executor.Report.Actor.Error\x12\x15\n\rerror_message\x18\x0b \x01(\t\"/\n\x05\x45rror\x12\x08\n\x04NONE\x10\x00\x12\x0e\n\nINIT_ERROR\x10\x01\x12\x0c\n\x08INTERNAL\x10\x02\x1a\x8a\x01\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12,\n\x05state\x18\x02 \x01(\x0e\x32\x1d.eolymp.executor.Report.State\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12+\n\x05steps\x18\n \x03(\x0b\x32\x1c.eolymp.executor.Report.Step\x1a\xe9\x07\n\x04Step\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x35\n\x07outcome\x18\x02 \x01(\x0e\x32$.eolymp.executor.Report.Step.Outcome\x12\x37\n\x07\x65xecute\x18\x0c \x01(\x0b\x32$.eolymp.executor.Report.Step.ExecuteH\x00\x12\x35\n\x06upload\x18\r \x01(\x0b\x32#.eolymp.executor.Report.Step.UploadH\x00\x12\x33\n\x05group\x18\x0e \x01(\x0b\x32\".eolymp.executor.Report.Step.GroupH\x00\x1a\xad\x04\n\x07\x45xecute\x12\r\n\x05\x61\x63tor\x18\x01 \x01(\t\x12>\n\x0b\x65xit_status\x18\x02 \x01(\x0e\x32).eolymp.executor.Report.Step.Execute.Exit\x12@\n\x06values\x18\x03 \x03(\x0b\x32\x30.eolymp.executor.Report.Step.Execute.ValuesEntry\x12\x17\n\x0fwall_time_usage\x18\x33 \x01(\r\x12\x17\n\x0fwall_time_limit\x18= \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18\x34 \x01(\r\x12\x16\n\x0e\x63pu_time_limit\x18> \x01(\r\x12\x14\n\x0cmemory_usage\x18\x35 \x01(\x04\x12\x14\n\x0cmemory_limit\x18? \x01(\x04\x12\x11\n\texit_code\x18\x46 \x01(\r\x12\x0e\n\x06signal\x18G \x01(\r\x12\x36\n\x0eresource_usage\x18P \x01(\x0b\x32\x1e.eolymp.executor.ResourceUsage\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x04\x45xit\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x0b\n\x07TIMEOUT\x10\x02\x12\x11\n\rCPU_EXHAUSTED\x10\x03\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x04\x12\x11\n\rRUNTIME_ERROR\x10\x05\x12\x0b\n\x07SKIPPED\x10\x06\x1a\x45\n\x06Upload\x12\x13\n\x0btarget_name\x18\x01 \x01(\t\x12\x12\n\ntarget_ern\x18\x02 \x01(\t\x12\x12\n\ntarget_url\x18\x03 \x01(\t\x1a@\n\x05Group\x12\x37\n\tprocesses\x18\x01 \x03(\x0b\x32$.eolymp.executor.Report.Step.Execute\"4\n\x07Outcome\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08\x43OMPLETE\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x42\x08\n\x06output\"h\n\x05State\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0b\n\x07\x42LOCKED\x10\x05\x12\x0b\n\x07SKIPPED\x10\x06\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.report_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _REPORT_STEP_EXECUTE_VALUESENTRY._options = None
  _REPORT_STEP_EXECUTE_VALUESENTRY._serialized_options = b'8\001'
  _REPORT._serialized_start=79
  _REPORT._serialized_end=1733
  _REPORT_ACTOR._serialized_start=313
  _REPORT_ACTOR._serialized_end=482
  _REPORT_ACTOR_ERROR._serialized_start=435
  _REPORT_ACTOR_ERROR._serialized_end=482
  _REPORT_RUN._serialized_start=485
  _REPORT_RUN._serialized_end=623
  _REPORT_STEP._serialized_start=626
  _REPORT_STEP._serialized_end=1627
  _REPORT_STEP_EXECUTE._serialized_start=869
  _REPORT_STEP_EXECUTE._serialized_end=1426
  _REPORT_STEP_EXECUTE_VALUESENTRY._serialized_start=1258
  _REPORT_STEP_EXECUTE_VALUESENTRY._serialized_end=1303
  _REPORT_STEP_EXECUTE_EXIT._serialized_start=1305
  _REPORT_STEP_EXECUTE_EXIT._serialized_end=1426
  _REPORT_STEP_UPLOAD._serialized_start=1428
  _REPORT_STEP_UPLOAD._serialized_end=1497
  _REPORT_STEP_GROUP._serialized_start=1499
  _REPORT_STEP_GROUP._serialized_end=1563
  _REPORT_STEP_OUTCOME._serialized_start=1565
  _REPORT_STEP_OUTCOME._serialized_end=1617
  _REPORT_STATE._serialized_start=1629
  _REPORT_STATE._serialized_end=1733
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/harmony/harmony.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.harmony import agreement_pb2 as eolymp_dot_harmony_dot_agreement__pb2
from eolymp.harmony import consent_pb2 as eolymp_dot_harmony_dot_consent__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/harmony/harmony.proto\x12\x0e\x65olymp.harmony\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/harmony/agreement.proto\x1a\x1c\x65olymp/harmony/consent.proto\"0\n\x13ListAgreementsInput\x12\x19\n\x11preferred_locales\x18\x01 \x03(\t\"@\n\x14ListAgreementsOutput\x12(\n\x05items\x18\x01 \x03(\x0b\x32\x19.eolymp.harmony.Agreement\"\'\n\x0fGetConsentInput\x12\x14\n\x0c\x61greement_id\x18\x01 \x01(\t\"<\n\x10GetConsentOutput\x12(\n\x07\x63onsent\x18\x01 \x01(\x0b\x32\x17.eolymp.harmony.Consent\"W\n\x0fSetConsentInput\x12\x14\n\x0c\x61greement_id\x18\x01 \x01(\t\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x1e.eolymp.harmony.Consent.Status\"<\n\x10SetConsentOutput\x12(\n\x07\x63onsent\x18\x01 \x01(\x0b\x32\x17.eolymp.harmony.Consent\"Z\n\x13\x46ollowShortcutInput\x12\x13\n\x0bshortcut_id\x18\x01 \x01(\t\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x1e.eolymp.harmony.Consent.Status\"\x16\n\x14\x46ollowShortcutOutput2\xd4\x04\n\x07Harmony\x12\x87\x01\n\x0eListAgreements\x12#.eolymp.harmony.ListAgreementsInput\x1a$.eolymp.harmony.ListAgreementsOutput\"*\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x15\x12\x13/harmony/agreements\x12\x92\x01\n\nGetConsent\x12\x1f.eolymp.harmony.GetConsentInput\x1a .eolymp.harmony.GetConsentOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02,\x12*/harmony/agreements/{agreement_id}/consent\x12\x92\x01\n\nSetConsent\x12\x1f.eolymp.harmony.SetConsentInput\x1a .eolymp.harmony.SetConsentOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02,\x1a*/harmony/agreements/{agreement_id}/consent\x12\x94\x01\n\x0e\x46ollowShortcut\x12#.eolymp.harmony.FollowShortcutInput\x1a$.eolymp.harmony.FollowShortcutOutput\"7\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\"\" /harmony/shortcuts/{shortcut_id}B1Z/github.com/eolymp/go-sdk/eolymp/harmony;harmonyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.harmony.harmony_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/harmony;harmony'
  _HARMONY.methods_by_name['ListAgreements']._options = None
  _HARMONY.methods_by_name['ListAgreements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\323\344\223\002\025\022\023/harmony/agreements'
  _HARMONY.methods_by_name['GetConsent']._options = None
  _HARMONY.methods_by_name['GetConsent']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\323\344\223\002,\022*/harmony/agreements/{agreement_id}/consent'
  _HARMONY.methods_by_name['SetConsent']._options = None
  _HARMONY.methods_by_name['SetConsent']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\323\344\223\002,\032*/harmony/agreements/{agreement_id}/consent'
  _HARMONY.methods_by_name['FollowShortcut']._options = None
  _HARMONY.methods_by_name['FollowShortcut']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\323\344\223\002\"\" /harmony/shortcuts/{shortcut_id}'
  _LISTAGREEMENTSINPUT._serialized_start=177
  _LISTAGREEMENTSINPUT._serialized_end=225
  _LISTAGREEMENTSOUTPUT._serialized_start=227
  _LISTAGREEMENTSOUTPUT._serialized_end=291
  _GETCONSENTINPUT._serialized_start=293
  _GETCONSENTINPUT._serialized_end=332
  _GETCONSENTOUTPUT._serialized_start=334
  _GETCONSENTOUTPUT._serialized_end=394
  _SETCONSENTINPUT._serialized_start=396
  _SETCONSENTINPUT._serialized_end=483
  _SETCONSENTOUTPUT._serialized_start=485
  _SETCONSENTOUTPUT._serialized_end=545
  _FOLLOWSHORTCUTINPUT._serialized_start=547
  _FOLLOWSHORTCUTINPUT._serialized_end=637
  _FOLLOWSHORTCUTOUTPUT._serialized_start=639
  _FOLLOWSHORTCUTOUTPUT._serialized_end=661
  _HARMONY._serialized_start=664
  _HARMONY._serialized_end=1260
# @@protoc_insertion_point(module_scope)
